<?php

// * * Requires Plugins: woocommerce
/**
 * Plugin Name: Addify Quantity Buttons
 * Plugin URI: https://woocommerce.com/vendor/addify/
 * Description: A plugin to add quantity buttons to WooCommerce products.
 * Version: 1.0.0
 * Author: Addify
 * Developed By: Addify
 * Author URI: https://woocommerce.com/vendor/addify/
 * Domain Path: /languages
 * Text Domain: addify-quantities-buttons
 * Support: https://woocommerce.com/vendor/addify/
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * WC requires at least: 3.0.9
 * WC tested up to: 6.7
 */

// Prevent direct access
if (!defined('ABSPATH')) {
	exit;
}
if (!class_exists('AQBS_Class')) {
	class AQBS_Class {
	



		public function __construct() {

			global $pagenow;
			
			$this->aqbs_define_constants();
			add_action('before_woocommerce_init', array( $this, 'aqbsw_Woo_Compatibility' ));
			register_deactivation_hook(__FILE__, array( $this, 'delete_plugin_data' ));//when plugin install & activating then remove existing data
			add_action('plugin_loaded', array( $this, 'aqbsw_plugin_loaded' )); //languages load
			if (( 'admin.php' == $pagenow ) && ( is_admin() )) {

				require_once AQBS_PLUGIN_DIR . 'includes/admin/admin.php';
				add_action('admin_enqueue_scripts', array( $this, 'enqueue_custom_admin_script' ));
			} else {
				require_once AQBS_PLUGIN_DIR . 'includes/front/front.php';
				add_action('wp_enqueue_scripts', array( $this, 'define_frontend_style_script' ));
			}
			add_action('wp_ajax_getborder_shape_action', array( $this, 'getBorderShape' ));
			add_action('wp_ajax_nopriv_getborder_shape_action', array( $this, 'getBorderShape' ));
		}

		public function aqbsw_Woo_Compatibility() {
			if (class_exists(\Automattic\WooCommerce\Utilities\FeaturesUtil::class)) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
			}
		}
		public  function enqueue_custom_admin_script() {

			wp_enqueue_media(); // Enqueue WordPress media uploader
			wp_enqueue_style('custom_quantity_button_style_css', AQBS_PLUGIN_URL . 'assets/css/admin.css', array(), AQBSW_VERSION);
			wp_enqueue_script(
				'aqbs-admin-scripts',
				AQBS_PLUGIN_URL . 'assets/js/admin/admin.js',
				array( 'jquery' ),
				'1.0',
				true
			);
		}
		public function aqbsw_plugin_loaded() {

			if (function_exists('load_plugin_textdomain')) {
				load_plugin_textdomain('addify-quantities-buttons', false, AQBS_PLUGIN_DIR . '/languages');
			}
		}

		public function define_frontend_style_script() {


			if (is_product() || is_cart()) {

				wp_enqueue_script('custom_quantity_button_script_front', AQBS_PLUGIN_URL . 'assets/js/front/script.js', array( 'jquery' ), AQBSW_VERSION, true);
				wp_localize_script('custom_quantity_button_script_front', 'my_ajax_object', array(
					'ajax_url' => admin_url('admin-ajax.php'),
					'nonce'    => wp_create_nonce('my_plugin_nonce'),
				));
				wp_enqueue_style('custom_quantity_button_style_css_front', AQBS_PLUGIN_URL . 'assets/css/front.css', array(), AQBSW_VERSION);
				wp_enqueue_style('font-awesome', AQBS_PLUGIN_URL . 'assets/css/front/css/all.min.css', array(), AQBSW_VERSION);
				// Verify the nonce on form submission

			}
		}
		private function aqbs_define_constants() {
			// Define constants
			if (!defined('AQBS_PLUGIN_DIR')) {
				define('AQBS_PLUGIN_DIR', plugin_dir_path(__FILE__));
			}
			if (!defined('AQBS_PLUGIN_URL')) {
				define('AQBS_PLUGIN_URL', plugin_dir_url(__FILE__));
			}
			if (!defined('AQBSW_VERSION')) {
				define('AQBSW_VERSION', '1.0.0');
			}
		}
		// delete Plugin Data
		public function delete_plugin_data() {
			$options_to_delete = array(
				'addify_quantity_btn_icon_plus',
				'addify_quantity_btn_icon_minus',
				'addify_quantity_btn_border_shape',
				'addify_quantity_btn_text_color',
				'addify_quantity_btn_border_shape',
				'addify_quantity_btn_border_color',
				'addify_quantity_btn_background_color',
				'addify_quantity_btn_hover_color',
				'addify_quantity_btn_font_family',

			);
			foreach ($options_to_delete as $option) {
				delete_option($option);
			}
		}

		public function getBorderShape() {
			// echo 'dd' . $_POST['security'];
			check_ajax_referer('my_plugin_nonce', 'security');
			$attr = isset($_POST['shape']) ? sanitize_text_field(wp_unslash($_POST['shape'])) : '';
			if ($attr) {
				$shape = esc_attr(get_option($attr));
				$btnIconUp = esc_attr(get_option('addify_quantity_btn_icon_plus'));
				$btnIconDown = esc_attr(get_option('addify_quantity_btn_icon_minus'));
				$IconDown = $btnIconDown ? '<i class="' . $btnIconDown . '"></i>' : '-';
				$IconUp = $btnIconUp ? '<i class="' . $btnIconUp . '"></i>' : '+';


				$textColor = esc_attr(get_option('addify_quantity_btn_text_color'));
				$btnShape = esc_attr(get_option('addify_quantity_btn_border_shape') == 'circle' ? '50%' : '0px');
				$btnBorderColor = esc_attr(get_option('addify_quantity_btn_border_color'));
				$btnBgColor = esc_attr(get_option('addify_quantity_btn_background_color'));
				$btnHoverColor = esc_attr(get_option('addify_quantity_btn_hover_color'));
				$btnFontFamily = esc_attr(get_option('addify_quantity_btn_font_family'));
			}
			if (isset($shape)) {
				$response = array(
					'shape' => $shape,
					'buttonIconUp' => $IconUp,
					'buttonIconDown' => $IconDown,
					'textColor' => $textColor,
					'btnShape' => $btnShape,
					'btnBorderColor' => $btnBorderColor,
					'btnBgColor' => $btnBgColor,
					'btnHoverColor' => $btnHoverColor,
					'btnFontFamily' => $btnFontFamily,
					'success' => true,
				);
				wp_send_json($response);
			}
		}
	}

	new AQBS_Class();
}
